@@ -1,9 +1,11 @@
 package Data::ModeMerge::Mode::DELETE;
-our $VERSION = '0.21';
+BEGIN {
+  $Data::ModeMerge::Mode::DELETE::VERSION = '0.24';
+}
 # ABSTRACT: Handler for Data::ModeMerge DELETE merge mode
 
 
-use Moose;
+use Any::Moose;
 extends 'Data::ModeMerge::Mode::Base';
 
 sub name { 'DELETE' }
@@ -71,7 +73,7 @@ sub merge_HASH_HASH {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Any::Moose;
 1;
 
 __END__
@@ -83,7 +85,7 @@ Data::ModeMerge::Mode::DELETE - Handler for Data::ModeMerge DELETE merge mode
 
 =head1 VERSION
 
-version 0.21
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -99,7 +101,7 @@ This is the class to handle DELETE merge mode.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Steven Haryanto.
+This software is copyright (c) 2010 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
